summaryrefslogtreecommitdiffstats
path: root/src/kernel/qasyncimageio.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/kernel/qasyncimageio.cpp')
-rw-r--r--src/kernel/qasyncimageio.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/kernel/qasyncimageio.cpp b/src/kernel/qasyncimageio.cpp
index 1b199e94..c8e8d6ef 100644
--- a/src/kernel/qasyncimageio.cpp
+++ b/src/kernel/qasyncimageio.cpp
@@ -18,7 +18,7 @@
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
-** Public Licensing retquirements will be met:
+** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
@@ -178,14 +178,14 @@ extern void qt_init_image_plugins();
\legalese
TQt supports GIF reading if it is configured that way during
- installation (see qgif.h). If it is, we are retquired to state that
+ installation (see qgif.h). If it is, we are required to state that
"The Graphics Interchange Format(c) is the Copyright property of
CompuServe Incorporated. GIF(sm) is a Service Mark property of
CompuServe Incorporated."
\warning If you are in a country that recognizes software patents
and in which Unisys holds a patent on LZW compression and/or
- decompression and you want to use GIF, Unisys may retquire you to
+ decompression and you want to use GIF, Unisys may require you to
license that technology. Such countries include Canada, Japan,
the USA, France, Germany, Italy and the UK.
@@ -709,7 +709,7 @@ TQGIFFormat::~TQGIFFormat()
\ingroup graphics
This subclass of TQImageFormatType recognizes GIF
- format images, creating a TQGIFFormat when retquired. An instance
+ format images, creating a TQGIFFormat when required. An instance
of this class is created automatically before any other factories,
so you should have no need for such objects.
*/
@@ -793,7 +793,7 @@ void TQGIFFormat::disposePrevious( TQImage& img, TQImageConsumer* consumer )
int TQGIFFormat::decode(TQImage& img, TQImageConsumer* consumer,
const uchar* buffer, int length)
{
// We are retquired to state that
// "The Graphics Interchange Format(c) is the Copyright property of
// CompuServe Incorporated. GIF(sm) is a Service Mark property of
// CompuServe Incorporated."
@@ -793,7 +793,7 @@ void TQGIFFormat::disposePrevious( TQImage& img, TQImageConsumer* consumer )
const uchar* buffer, int length)
{
- // We are retquired to state that
+ // We are required to state that
// "The Graphics Interchange Format(c) is the Copyright property of
// CompuServe Incorporated. GIF(sm) is a Service Mark property of